#include "ros/ros.h"                //ROS必要的文件
#include "std_msgs/Int16.h"  //16位数组消息类型
#include <sstream>
/*----------------------------------------------------------------------------------------------------------------------
函数说明: 建立一个hcrControl 节点，发布 电机控制 motor1 和 motor2两个消息
                  这两个消息被HCR的arduoino主板订阅，用于控制电机
参数说明:  无
返回值  :  无
----------------------------------------------------------------------------------------------------------------------*/
int main(int argc, char **argv)
{
    int i;
    ros::init(argc, argv, "hcrControl");     //设置唯一的节点名称 hcrControl
    ros::NodeHandle n;      //节点句柄
	//将节点设置为发布者，并将发布的主题的类型和名称告知节点管理器，消息名称motor，缓冲区1000
    ros::Publisher pub1 = n.advertise<std_msgs::Int16>("motor1", 1000);
    ros::Publisher pub2 = n.advertise<std_msgs::Int16>("motor2", 1000);
	ros::Rate loop_rate(10);  //发送速率为10hz

    std_msgs::Int16 msg1;   //创建一个 16位 消息变量
    std_msgs::Int16 msg2;   //创建一个 16位 消息变量
    msg1.data = 0;
    msg2.data = 0;

    while (ros::ok())	//收到Ctrl+C 后停止
	{
        for(i=0;i<164;i++)  //HCR的两个轮子从0速度到前进最大速度
        {
            msg1.data = i;
            msg2.data = i;
            pub1.publish(msg1);		//发布消息
            pub2.publish(msg2);		//发布消息
            ros::spinOnce();    //如果有订阅者出现，ROS就会更新和读取所有主题
            loop_rate.sleep();	//按照10hz的频率挂起
        }
        for(i=0;i>-164;i--)  //HCR的两个轮子从0速度到后退最大速度
        {
            msg1.data = i;
            msg2.data = i;
            pub1.publish(msg1);		//发布消息
            pub2.publish(msg2);		//发布消息
            ros::spinOnce();    //如果有订阅者出现，ROS就会更新和读取所有主题
            loop_rate.sleep();	//按照10hz的频率挂起
        }
    }
	return 0;
}
